#
# spec file for package habootstrap-formula
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Specfile_guidelines

Name:           habootstrap-formula
Group:          System/Packages
Version:        0.4.3+git.1625210910.7b0645d
Release:        1.8
Summary:        HA cluster (crmsh) deployment salt formula

License:        Apache-2.0
Url:            https://github.com/SUSE/%{name}
Source0:        %{name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Requires:       salt-shaptools
%if 0%{?suse_version} < 1500
Recommends:     salt-formulas-configuration
%else
Requires:       salt-formulas-configuration
%endif

%define fname cluster
%define fdir  %{_datadir}/salt-formulas
%define ftemplates templates

%description
HA cluster salt deployment formula. This formula is capable to perform
the HA cluster bootstrap actions (init, join, remove) using standalone salt
or via SUSE Manager formulas with forms, available on SUSE Manager 4.0.

In order to use the formula, salt must be available in the system. The package comes automatically
in SLE15. To use it in SLE12, salt (and it sub-components) comes from the Advanced systems management
module, which can be added running the `SUSEConnect -p sle-module-adv-systems-management/12/{{ arch }}`

%prep
%setup -q

%build

%install

mkdir -p %{buildroot}%{fdir}/states/%{fname}
mkdir -p %{buildroot}%{fdir}/metadata/%{fname}
cp -R %{fname} %{buildroot}%{fdir}/states
cp -R %{ftemplates} %{buildroot}%{fdir}/states/%{fname}
cp -R form.yml pillar.example %{buildroot}%{fdir}/metadata/%{fname}
if [ -f metadata.yml ]
then
  cp -R metadata.yml %{buildroot}%{fdir}/metadata/%{fname}
fi


%files
%defattr(-,root,root,-)
%if 0%{?sle_version} < 120300
%doc README.md LICENSE
%else
%doc README.md
%license LICENSE
%endif

%dir %attr(0755, root, salt) %{fdir}
%dir %attr(0755, root, salt) %{fdir}/states
%dir %attr(0755, root, salt) %{fdir}/metadata

%attr(0755, root, salt) %{fdir}/states/%{fname}
%attr(0755, root, salt) %{fdir}/states/%{fname}/%{ftemplates}
%attr(0755, root, salt) %{fdir}/metadata/%{fname}

%changelog
* Mon Jun 28 2021 Eike Waldt <waldt@b1-systems.de>
- Version bump 0.4.3
  * Add packages to enable native fencing for microsoft-azure
  * Documentation on how to enable native fencing
* Thu Mar 11 2021 Cédric Bosdonnat <cbosdonnat@suse.com>
- Version bump 0.4.2
  * Fix SUSE Manager integration
  * Move SUMA pillar data modifications to map.jinja file <xarbulu@suse.com>
  (bsc#1181731)
* Wed Jan 27 2021 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.4.1
  * Ass sshkeys to default dictionary to allow usage with this item
  (bsc#1181453)
* Wed Jan 20 2021 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.4.0
  * Change salt-formulas-configuration requirement in SLE12 codestream
  to a recommendation
  (bsc#1177860)
* Tue Jan 19 2021 Xabier Arbulu <xarbulu@suse.com>
- Remove lock states as this is done in crmsh now
- Fix ssh keys management to run them once the first node is
  initialized
* Tue Jan 19 2021 Aleksei Burlakov <aburlakov@suse.com>
- Remove --no-overwrite-sshkey option from the formula
* Mon Jan 18 2021 Aleksei Burlakov <aburlakov@suse.com>
- qdevice support: it can be created when initializing a cluster
* Thu Oct 15 2020 Simranpal Singh <simranpal.singh@suse.com>
- Version bump 0.3.11
  * Update the prevalidation logic to check for valid sbd entries (jsc#SLE-4047)
* Thu Oct  8 2020 Dario Maiocchi <dmaiocchi@suse.com>
- Version bump 0.3.10
  * Improve Formula with form description (jsc#SLE-4047)
* Mon Oct  5 2020 Simranpal Singh <simranpal.singh@suse.com>
- Update the SUMA form.yml file and prevalidation state with latest changes in project
* Thu Sep  3 2020 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.3.9
  * Add lock mechanism to the cluster join process to avoid issues
  when multiple nodes are joining in parallel
  (jsc#SLE-4047)
* Thu Aug 20 2020 Simranpal Singh <simranpal.singh@suse.com>
- Version bump 0.3.8
  * Include the pillar example file in package
  (bsc#1174994)
* Thu Jun  4 2020 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.3.7
  * Make diskless sbd and using disks self exclusive (bsc#1172432)
  (jsc#ECO-1965, jsc#SLE-4047)
* Thu May 21 2020 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.3.6
  * Add the option to configure the cluster properties and defaults
  * Add the option to configure the sbd resource parameters
  (bsc#1170702)
* Fri May 15 2020 Stefano Torresi <stefano.torresi@suse.com>
- Version bump 0.3.5
  * Change monitoring settings
* Fri Apr 17 2020 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.3.4
  * Autodetect GCP instance name and add it to the grains file
  * Install the correct packages for the GCP resources
  (bsc#1161898, bsc#1160933)
* Fri Mar 27 2020 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.3.3
  * Autodetect GCP instance id and add it to the grains file
  Thu Mar  5 10:29:22 UTC 2020 - Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.3.2
  * Add new option to configure corosync configuration file
* Tue Mar  3 2020 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.3.1
  * Add the required packages to use gcp specific agents
  (bsc#1161898, bsc#1160933)
* Mon Feb  3 2020 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.3.0
  * Add --no-overwrite-sshkey option to the formula
  * Add automatic cloud detection
  * Add option to set multiple sbd disks to the cluster
  * Move the cluster configure part to a new state to be executed
    even when joining executions
  * Add option to update hacluster user password
  (bsc#1165156, jsc#SLE-4031, boo#1137989)
* Thu Nov 28 2019 Simranpal Singh <simranpal.singh@suse.com>
- Version bump 0.2.10
  * Install 'socat' package on the Azure platform
* Wed Oct 30 2019 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.2.9
  * Fix issue with file permissions during package installation in
    /usr/share/salt-formulas (0755, root, salt)
    (boo#1142306)
* Wed Oct 16 2019 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.2.8
  * Add customizable timeout to the join process and rename join_timer to
  wait_for_initialization
* Wed Sep 18 2019 Dario Maiocchi <dmaiocchi@suse.com>
- remove and replace hawk-apiserver with prometheus-ha_cluster_exporter pkg
* Wed Sep  4 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Update the pkg.info_available call to avoid repositories refresh as
  it may cause errors
- Add packages and ha_exporter options to the SUMA form.yml file
* Sun Aug 25 2019 Ayoub Belarbi <abelarbi@suse.de>
- Version bump 0.2.6
  * Fix typo in Pillar attribute name
* Wed Aug 21 2019 Ayoub Belarbi <abelarbi@suse.de>
- Version bump 0.2.5
  * Add HA monitoring to the formula
* Mon Jul 22 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Version bump 0.2.4
  * Fix issue with file permissions during package installation in
    /usr/share/salt-formulas
    (boo#1142306)
* Fri Jul  5 2019 Dario Maiocchi <dmaiocchi@suse.com>
- Make pkg.install more resilient, allowing retries during install
* Tue Jul  2 2019 Diego Vinicius Akechi <dakechi@suse.com>
- Version bump 0.2.2
  * Change the salt-formula directories permissions to 0750 to avoid
    conflicts with the package salt-standalone-formulas-configuration.
  * Correct the required package name to
    salt-standalone-formulas-configuration
* Tue Jun 11 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Create package version 0.2.1 with fixed spec files. Now the package
  is available in all SLE12 and SLE15 versions (boo#1137989, jsc#SLE-4031)
* Fri May 31 2019 Diego Vinicius Akechi <dakechi@suse.com>
- Version bump 0.2.0
  * Include the salt-formulas-configuration dependency on
    SLE/Leap 15-SP1 and higher. This package configures the shared salt
    formulas location (/usr/share/salt-formulas) to be used by SUMA 4.0
    or salt in standalone mode.
  * Drops the habootstrap-formula-suma package, as the forms metadata
    will be available only on SUMA 4.0 using the shared location.
* Thu May 16 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Remove network repository installation
* Thu Apr 25 2019 Diego Vinicius Akechi <dakechi@suse.com>
- Changed requires from salt-saphana to salt-shaptools.
* Tue Feb 19 2019 dakechi@suse.com
- Update to version 1.0.0+git.1550242845.0e69ab8:
  * Allow pre-configured packages
  * Update package installation to use ha pattern for SUSE distros
  * Update join_timer parameter description
  * Allow custom timer before cluster join
  * Improve pre validation state to check the proper parameters
  * Create suma form and adapt states to that
  * Add new feature to the formula: - Ntp connection - SSH keys management - Watchdog - Mandatory pacakges and RA packages
  * Add new options to configure the cluster in creation
  * Update ha formula to use crmsh salt code
  * Updated README and added comment about NET_IP in Vagrantfile
- Consolidate the SUMA specific package into one .spec file
* Fri Sep 14 2018 kgronlund@suse.com
- Update to version 1.0.0+git.1536931866.e47f6ce:
  * Pillar data has to be defined in a separate SLS
  * Revised pillar data layout to make usage simpler
  * Drop extraneous dash in join args
  * Set group in metadata.yml
* Thu Sep  6 2018 kgronlund@suse.com
- Update to version 1.0.0+git.1536240306.8442de8:
  * Add metadata.yml
* Thu Sep  6 2018 kgronlund@suse.com
- Initial version
